# Quantsim Simulation package

Contains the simulation code for the application


## Project structure
```
docs/           # Documentation
quantsim/       # Library
 | - Circuit/   # Circuit wise representation
 | - gates/     # contains the basic gates
tests/      # Tests

```
